# ANYstructure
![Logo](https://docs.google.com/uc?id=1h0y3763tcvXQzxqX3B8p91UzNo9cEb6C)

Download OR install using:
------------------------------------------------------------------------
__pip install anystructure__

After installing on PIP run ANYstructure (.exe) in the command line to execute the app.

Alternatively: 

import ANYstructure.\_\_main\_\_ as run

run.main()

------------------------------------------------------------------------

Windows installable EXE-link: https://sourceforge.net/projects/anystructure/

------------------------------------------------------------------------

GUI based steel structure calculation tool.
 
 The following is calculated:
  - Minimum plate thickness (DNVGL-OS-C101)
  - Minimum section modulus of stiffener/plate (DNVGL-OS-C101)
  - Minimum shear area (DNVGL-OS-C101)
  - Buckling (DNVGL-RP-C201)
  - Fatigue for plate/stiffener connection (DNVGL-RP-C203)

Compartments (tank pressures) are created automatically.

Pressures on external hull (or any other generic location) is defined by specifying equations.

You can optimize single plate/stiffener field or multiple.

PLEASE CONTRIBUTE. 
For windows executable (.exe) version for non-coders, use the link below.
Note that I am looking for contributions. Non-coders can verify, make documentation, suggest improvements etc. Point
is: please do more than just use the tool and stay silent :)

Feedback: audunarn@gmail.com or discuss on github.

Please like, share or comment on LinkedIn: https://www.linkedin.com/in/audun-arnesen-nyhus-6aa17118/

Screenshot (this example can be loaded from file "ship_section_example.txt"):

![picture](https://docs.google.com/uc?id=1AWu0Twqd3tQKjUKPWXBFVwosUZTvlq4t)
